===========================
Welcome to django-modeltree
===========================

.. image:: https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C%203.12%20%7C%203.13-blue
   :target: https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C%203.12%20%7C%203.13-blue
   :alt: python: 3.7, 3.8, 3.9, 3.10, 3.11, 3.12, 3.13

.. image:: https://img.shields.io/badge/django-2.2%20%7C%203.0%20%7C%203.1%20%7C%203.2%20%7C%204.0%20%7C%204.1%20%7C%204.2%20%7C%205.0%20%7C%205.1%20%7C%205.2%20%7C%206.0-orange
   :target: https://img.shields.io/badge/django-2.2%20%7C%203.0%20%7C%203.1%20%7C%203.2%20%7C%204.0%20%7C%204.1%20%7C%204.2%20%7C%205.0%20%7C%205.1%20%7C%205.2%20%7C%206.0-orange
   :alt: django: 2.2, 3.0, 3.1, 3.2, 4.0, 4.1, 4.2, 5.0, 5.1, 5.2, 6.0

.. image:: https://github.com/thomst/django-modeltree/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/thomst/django-modeltree/actions/workflows/ci.yml
   :alt: Run tests for django-modeltree

.. image:: https://coveralls.io/repos/github/thomst/django-modeltree/badge.svg?branch=master
   :target: https://coveralls.io/github/thomst/django-modeltree?branch=master
   :alt: Coveralls


About
=====
Do you have a model layout with various relations and looking for a way to
navigate it with ease? Then django-modeltree is what you are looking for. Build
your modeltree in a single line and accessing related models and their objects
in a elegant and performant way. No need for complex query building anymore.
Find out how this works `here <https://thomst.github.io/django-modeltree/>`_.


Links
=====

* `Github <https://github.com/thomst/django-modeltree>`_
* `Docs <https://thomst.github.io/django-modeltree/>`_


Installation
============
Install from pypi.org::

    pip install django-modeltree

